//
//  DataVersionsUpdateManager+UpdateHandler.h
//  QihooBrowser
//
//  Created by gang ji on 4/11/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "DataVersionsUpdateManager.h"

#define kUpdateInfoHandler @"kUpdateInfoHandler"
#define kUpdateInfoResult @"kUpdateInfoResult"
@class VersionsInfoData;
/** 
 *	需要各功能模块处理器实现的代理。
 */
@protocol FeatureUpdateHandler <NSObject>

/** 
 *	处理器实现这个方法，处理其升级以及升级后需要回调相应的接口函数。
 *	@param  [in]   filePath 处理器需要解析的功能项升级文件路径
 *	@param  [in]   callbackTarget 处理器升级后回调函数的接收者对象
 *	@param  [in]   callback 处理器升级后的回调函数
 */
-(void)updateWithFile:(NSString *)filePath callBackTarget:(id)callbackTarget finishedCallBackFunction:(SEL)callback;

@end

/** 
 *	DataVersionsUpdateManager 分类用以管理各功能模块的升级处理器。
 */
@interface DataVersionsUpdateManager (UpdateHandler)

+(void)setDataUpgradeCachePath:(NSString *)path;
/** 
 *	注册函数，各功能模块通过这个方法注册其各自的处理器。
 *  注册时会对该处理器retain计数加1.
 *  注册时会生成一个以功能项名称为键，处理器对象为值的键值对
 *	@param  [in]   featureName 注册的功能项名称
 *	@param  [in]   handler 注册的处理器对象
 */
+(void)registerWithFeatureName:(NSString *)featureName handler:(id)handler;

/** 
 *	注销函数，各功能模块通过这个方法注销其各自的处理器。
 *  注销时会对该处理器retain计数减1.
 *	@param  [in]   featureName 要注销的功能项名称
 */
+(void)unRegisterWithFeatureName:(NSString *)featureName;


/** 
 *	全部功能项下载后，分发数据给各处理器。
 *  程序通过功能项名称获得处理器对象，调用处理器实现的接口函数，通知进行升级
 *	@param  [in]   data 待分发的数据，数据中包含待下载项。
 */
-(void)dispatchDownloadResultToHandler:(NSArray *)resultData;


/** 
 *	处理器处理完后的回调函数。
 *  该回调函数被调用后，会更新该处理器对应的功能项版本信息。
 *	@param  [in]   handler 已经升级完的处理器对象。
 */
-(void)updateFinishedForHandler:(NSDictionary *)updateUserInfo;


-(NSString *)urlForJS12306;

-(NSString *)urlForTicketQuery12306;

@end
